package VMOMI::HostFirewallRulePortType;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
